@@ -1,7 +1,7 @@
 #
-# $Id: ResponseParameters.pl,v 26.1 2004/04/08 13:04:24 biersma Exp $
+# $Id: ResponseParameters.pl,v 27.9 2007/01/11 20:20:04 molinam Exp $
 #
-# (c) 1999-2004 Morgan Stanley Dean Witter and Co.
+# (c) 1999-2007 Morgan Stanley Dean Witter and Co.
 # See ..../src/LICENSE for terms of distribution.
 #
 
@@ -11,47 +11,88 @@ package MQSeries::Command::MQSC;
   (
    QueueManager =>
    {
+    ACCMQI	=> [ "MQIAccounting" ],
+    ACCTQ	=> [ "QueueAccounting",		$ResponseValues{QMgrAccounting} ],
+    ACTCHL	=> [ "MaxActiveChannels" ],
+    ACTIVREC	=> [ "ActivityRecording",	$ResponseValues{ActivityRecording} ],
+    ADOPTCHK	=> [ "AdoptNewMCACheck",	$ResponseValues{AdoptNewMCACheck} ],
+    ADOPTMCA	=> [ "AdoptNewMCAType",		$ResponseValues{AdoptNewMCAType} ],
     ALTTIME	=> [ "AlterationTime" ],
     ALTDATE	=> [ "AlterationDate" ],
     AUTHOREV	=> [ "AuthorityEvent", 		$ResponseValues{Enabled} ],
+    BRIDGEEV	=> [ "BridgeEvent",		$ResponseValues{Enabled} ],
     CCSID	=> [ "CodedCharSetId" ],
     CHAD	=> [ "ChannelAutoDef",		$ResponseValues{Enabled} ],
     CHADEV	=> [ "ChannelAutoDefEvent",	$ResponseValues{Enabled} ],
     CHADEXIT	=> [ "ChannelAutoDefExit" ],
+    CHIADAPS	=> [ "ChinitAdapters" ],
+    CHIDISPS	=> [ "ChinitDispatchers" ],
+    CHISERVP	=> [ "ChinitServiceParm" ],
+    CHLEV	=> [ "ChannelEvent",		$ResponseValues{ChannelEvent} ],
     CLWLEXIT	=> [ "ClusterWorkLoadExit" ],
     CLWLDATA	=> [ "ClusterWorkLoadData" ],
     CLWLLEN 	=> [ "ClusterWorkLoadLength" ],
+    CLWLMRUC 	=> [ "CLWLMRUChannels" ],
+    CLWLUSEQ 	=> [ "CLWLUseQ",		$ResponseValues{CLWLUseQ} ],
+    CMDEV	=> [ "CommandEvent",		$ResponseValues{CommandEvent} ],
     CMDLEVEL	=> [ "CommandLevel" ],
     COMMANDQ	=> [ "CommandInputQName" ],
     CONFIGEV    => [ "ConfigurationEvent",      $ResponseValues{Enabled} ],
-    CPILEVEL	=> [ "" ],
+    CPILEVEL	=> [ "CPILevel" ],
     DEADQ	=> [ "DeadLetterQName" ],
     DEFXMITQ	=> [ "DefXmitQName" ],
     DESCR	=> [ "QMgrDesc" ],
     DISTL	=> [ "DistLists",		$ResponseValues{Yes} ],
+    DNSGROUP	=> [ "DNSGroup" ],
+    DNSWLM	=> [ "DNSWLM",			$ResponseValues{Yes} ],
     EXPRYINT    => [ "ExpiryInterval" ],
     IGQ         => [ "IntraGroupQueueing",      $ResponseValues{Enabled} ],
-    IGQAUT      => [ "IntraGroupAuthority",     $ResponseValues{IntraGroupAuthority} ],
-    IGQUSER     => [ "IntraGroupUser" ],
+    IGQAUT      => [ "IGQPutAuthority",         $ResponseValues{IGQPutAuthority} ],
+    IGQUSER     => [ "IGQUserid" ],
     INHIBTEV	=> [ "InhibitEvent",		$ResponseValues{Enabled} ],
+    IPADDRV	=> [ "IPAddressVersion",	$ResponseValues{IPAddressVersion} ],
     LOCALEV	=> [ "LocalEvent",		$ResponseValues{Enabled} ],
+    LSTRTMR	=> [ "ListenerTimer" ],
+    LU62ARM	=> [ "LU62ARMSuffix" ],
+    LU62CHL	=> [ "LU62Channels" ],
+    LUGROUP	=> [ "LUGroupName" ],
+    LUNAME	=> [ "LUName" ],
+    MAXCHL	=> [ "MaxChannels" ],
     MAXHANDS	=> [ "MaxHandles" ],
     MAXMSGL	=> [ "MaxMsgLength" ],
     MAXPRTY	=> [ "MaxPriority" ],
     MAXUMSGS	=> [ "MaxUncommittedMsgs" ],
+    MONACLS     => [ "ClusterSenderMonitoringDefault", $ResponseValues{ClusterSenderMonitoringDefault} ],
+    MONCHL	=> [ "ChannelMonitoring",	$ResponseValues{ChannelMonitoring} ],
+    MONQ	=> [ "QueueMonitoring",		$ResponseValues{QMgrMonitoring} ],
+    OPORTMAX	=> [ "OutboundPortMax" ],
+    OPORTMIN	=> [ "OutboundPortMin" ],
     PERFMEV	=> [ "PerformanceEvent",	$ResponseValues{Enabled} ],
     PLATFORM	=> [ "Platform", ],
     QMID	=> [ "QMgrIdentifier" ],
     QMNAME	=> [ "QMgrName" ],
     QSGNAME     => [ "QSharingGroupName" ],
+    RCVTMIN	=> [ "ReceiveTimeoutMin" ],
+    RCVTIME	=> [ "ReceiveTimeout" ],
+    RCVTTYPE	=> [ "ReceiveTimeoutType",	$ResponseValues{ReceiveTimeoutType} ],
     REMOTEEV	=> [ "RemoteEvent",		$ResponseValues{Enabled} ],
     REPOS	=> [ "RepositoryName" ],
     REPOSNL	=> [ "RepositoryNamelist" ],
+    ROUTEREC    => [ "TraceRouteRecording",	$ResponseValues{TraceRouteRecording} ],
+    SQQMNAME    => [ "SharedQQmgrName",		$ResponseValues{SharedQQmgrName} ],
     SSLCRLNL    => [ "SSLCRLNamelist" ],
+    SSLEV	=> [ "SSLEvent",		$ResponseValues{Enabled} ],
     SSLKEYR     => [ "SSLKeyRepository" ],
+    SSLRKEYC	=> [ "SSLKeyResetCount" ],
     SSLTASKS    => [ "SSLTasks" ],
     STRSTPEV	=> [ "StartStopEvent",		$ResponseValues{Enabled} ],
     SYNCPT	=> [ "SyncPoint",		$ResponseValues{Available} ],
+    TCPCHL	=> [ "TCPChannels" ],
+    TCPKEEP	=> [ "TCPKeepAlive",		$ResponseValues{Yes} ],
+    TCPNAME	=> [ "TCPName" ],
+    TCPSTACK	=> [ "TCPStackType",		$ResponseValues{TCPStackType} ],
+    TRAXTBL	=> [ "ChinitTraceTableSize" ],
+    TRAXSTR	=> [ "ChinitTraceAutoStart",	$ResponseValues{Yes} ],
     TRIGINT	=> [ "TriggerInterval" ],
    },
 
@@ -67,16 +108,22 @@ package MQSeries::Command::MQSC;
 
     ALTTIME	=> [ "AlterationTime" ],
     ALTDATE	=> [ "AlterationDate" ],
-
-    QSGDISP     => [ "QSharingGroupDisposition", $ResponseValues{QSharingGroupDisposition} ],
+    QSGDISP     => [ "QSGDisposition",		$ResponseValues{QSGDisposition} ],
+    #QSGDISP     => [ "QSGDisposition",		$ResponseValues{QSGDisposition} ],
    },
 
    Queue =>
    {
+    ACCTQ	=> [ "QueueAccounting",		$ResponseValues{QueueAccounting} ],
     BOQNAME	=> [ "BackoutRequeueName" ],
     BOTHRESH	=> [ "BackoutThreshold" ],
-    CFSTRUCT    => [ "CouplingStructure" ],
-    CHLDISP     => [ "ChannelDisposition" ],
+    CFSTRUCT    => [ "CFStructure" ],
+   # CFSTRUCT    => [ "CFStructure" ],
+#   CHLDISP     => [ "ChannelDisposition" ],
+    CLUSDATE    => [ "ClusterDate" ],
+    CLWLPRTY	=> [ "CLWLQueuePriority" ],
+    CLWLRANK	=> [ "CLWLQueueRank" ],
+    CLWLUSEQ	=> [ "CLWLUseQ",		$ResponseValues{CLWLUseQ} ],
     CMDSCOPE    => [ "CommandScope" ],
     CRDATE	=> [ "CreationDate" ],
     CRTIME	=> [ "CreationTime" ],
@@ -89,13 +136,14 @@ package MQSeries::Command::MQSC;
     DISTL	=> [ "DistLists",		$ResponseValues{Yes} ],
     GET		=> [ "InhibitGet",		$ResponseValues{Disabled} ],
     IGQ         => [ "IntraGroupQueueing" ],
-    IGQAUT      => [ "IntraGroupAuthority" ],
+    IGQAUT      => [ "IGQPutAuthority" ],
     IGQUSER     => [ "IntraGroupUser" ],
     INDXTYPE	=> [ "IndexType",		$ResponseValues{IndexType} ],
     INITQ	=> [ "InitiationQName" ],
     IPPROCS	=> [ "OpenInputCount" ],
     MAXDEPTH	=> [ "MaxQDepth" ],
     MAXMSGL	=> [ "MaxMsgLength" ],
+    MONQ	=> [ "QueueMonitoring",		$ResponseValues{QueueMonitoring} ],
     MSGDLVSQ	=> [ "MsgDeliverySequence",	$ResponseValues{MsgDeliverySequence} ],
     NPMCLASS    => [ "NonPersistentMsgClass",   $ResponseValues{NonPersistentMsgClass} ],
     OPPROCS	=> [ "OpenOutputCount" ],
@@ -111,7 +159,8 @@ package MQSeries::Command::MQSC;
     QSVCIEV	=> [ "QServiceIntervalEvent",   $ResponseValues{QServiceIntervalEvent} ],
     TYPE	=> [ "QType",  			$ResponseValues{QType} ],
     QUEUE	=> [ "QName" ],
-    QSGDISP     => [ "QSharingGroupDisposition", $ResponseValues{QSharingGroupDisposition} ],
+   # QSGDISP     => [ "QSGDisposition" , $ResponseValues{QSGDisposition} ],
+    QSGDISP     => [ "QSGDisposition", $ResponseValues{QSGDisposition} ],
     QSGNAME     => [ "QSharingGroupName" ],
     RETINTVL	=> [ "RetentionInterval" ],
     RNAME	=> [ "RemoteQName" ],
@@ -119,6 +168,7 @@ package MQSeries::Command::MQSC;
     SCOPE	=> [ "Scope",			$ResponseValues{Scope} ],
     STGCLASS	=> [ "StorageClass" ],
     TARGQ	=> [ "BaseQName" ],
+    TPIPE	=> [ "TPipeNames" ],
     TRIGDATA	=> [ "TriggerData" ],
     TRIGDPTH	=> [ "TriggerDepth" ],
     TRIGMPRI	=> [ "TriggerMsgPriority" ],
@@ -135,7 +185,6 @@ package MQSeries::Command::MQSC;
 
     ALTTIME	=> [ "AlterationTime" ],
     ALTDATE	=> [ "AlterationDate" ],
-    CLUSDATE	=> [ "ClusterDate" ],
     CLUSNL   	=> [ "ClusterNamelist" ],
     CLUSQMGR 	=> [ "QMgrName" ],
     CLUSQT  	=> [ "ClusterQType",		$ResponseValues{ClusterQType} ],
@@ -167,6 +216,11 @@ package MQSeries::Command::MQSC;
     CHSTADA	=> [ "ChannelStartDate" ],
     CHSTATI	=> [ "ChannelStartTime" ],
     CHSTATUS	=> [ "ChannelName" ],
+    CLWLRANK    => [ "CLWLChannelRank" ],
+    CLWLPRTY    => [ "CLWLChannelPriority" ],
+    CLWLWGHT    => [ "CLWLChannelWeight" ],
+    COMPHDR	=> [ "HeaderCompression",	$ResponseValues{Compression} ],
+    COMPMSG	=> [ "MessageCompression",	$ResponseValues{MessageCompression} ],
     CURLUWID	=> [ "CurrentLUWID" ],
     CURMSGS	=> [ "CurrentMsgs" ],
     CURSEQNO	=> [ "CurrentSequenceNumber" ],
@@ -178,6 +232,7 @@ package MQSeries::Command::MQSC;
     LSTMSGTI	=> [ "LastMsgTime" ],
     LSTSEQNO	=> [ "LastSequenceNumber" ],
     MCASTAT	=> [ "MCAStatus",		$ResponseValues{MCAStatus} ],
+    MONCHL	=> [ "ChannelMonitoring",	$ResponseValues{MonitoringDft} ],
     MSGS	=> [ "Msgs" ],
     SHORTRTS	=> [ "ShortRetriesLeft" ],
     STATUS	=> [ "ChannelStatus",		$ResponseValues{ChannelStatus} ],
@@ -200,7 +255,7 @@ package MQSeries::Command::MQSC;
     DESCR	=> [ "ChannelDesc" ],
     DISCINT	=> [ "DiscInterval" ],
     HBINT	=> [ "HeartbeatInterval" ],
-    KAINT       => [ "KeepAliveInterval" ],
+    KAINT       => [ "KeepAliveInterval",	$ResponseValues{KeepAliveInterval} ],
     LOCLADDR    => [ "LocalAddress" ],
     LONGRTY	=> [ "LongRetryCount" ],
     LONGTMR	=> [ "LongRetryInterval" ],
@@ -212,7 +267,7 @@ package MQSeries::Command::MQSC;
     MREXIT	=> [ "MsgRetryExit" ],
     MRDATA	=> [ "MsgRetryUserData" ],
     MRRTY	=> [ "MsgRetryCount" ],
-    MRTMT	=> [ "MsgRetryInterval" ],
+    MRTMR	=> [ "MsgRetryInterval" ],
     MSGDATA	=> [ "MsgUserData" ],
     MSGEXIT	=> [ "MsgExit" ],
     NPMSPEED	=> [ "NonPersistentMsgSpeed",   $ResponseValues{NonPersistentMsgSpeed} ],
@@ -244,8 +299,9 @@ package MQSeries::Command::MQSC;
     CLUSNL   	=> [ "ClusterNamelist" ],
     NETPRTY 	=> [ "NetworkPriority" ],
 
-    CHLDISP     => [ "ChannelDisposition",      $ResponseValues{ChannelDisposition} ],
-    QSGDISP     => [ "QSharingGroupDisposition", $ResponseValues{QSharingGroupDisposition} ],
+    CHLDISP     => [ "ChannelDisposition",	$ResponseValues{ChannelDisposition} ],
+    QSGDISP     => [ "QSGDisposition", $ResponseValues{QSGDisposition} ],
+   # QSGDISP     => [ "QSGDisposition",		$ResponseValues{QSGDisposition} ],
    },
 
    Namelist =>
@@ -256,8 +312,9 @@ package MQSeries::Command::MQSC;
     NAMELIST	=> [ "NamelistName" ],
     NAMCOUNT  	=> [ "NameCount" ],
     NAMES   	=> [ "Names" ],
-    NLTYPE      => [ "NamelistType",            $ResponseValues{NamelistType} ],
-    QSGDISP     => [ "QSharingGroupDisposition", $ResponseValues{QSharingGroupDisposition} ],
+    NLTYPE      => [ "NamelistType",		$ResponseValues{NamelistType} ],
+    QSGDISP     => [ "QSGDisposition", $ResponseValues{QSGDisposition} ],
+   # QSGDISP     => [ "QSGDisposition",		$ResponseValues{QSGDisposition} ],
    },
 
    StorageClass =>
@@ -266,8 +323,10 @@ package MQSeries::Command::MQSC;
     ALTTIME	=> [ "AlterationTime" ],
     ALTDATE	=> [ "AlterationDate" ],
     DESCR	=> [ "StorageClassDesc" ],
+    PASSTKTA	=> [ "PassTicketApplication" ],
     PSID	=> [ "PageSetId" ],
-    QSGDISP     => [ "QSharingGroupDisposition", $ResponseValues{QSharingGroupDisposition} ],
+    QSGDISP     => [ "QSGDisposition",		$ResponseValues{QSGDisposition} ],
+   # QSGDISP     => [ "QSGDisposition",		$ResponseValues{QSGDisposition} ],
     XCFGNAME	=> [ "XCFGroupName" ],
     XCFMNAME	=> [ "XCFMemberName" ],
    },
@@ -351,7 +410,8 @@ package MQSeries::Command::MQSC;
     OUTPUT      => [ "Output",                  $ResponseValues{Yes} ],
     PSBNAME     => [ "PSBName" ],
     PSTID       => [ "PSTId" ],
-    QSGDISP     => [ "QSharingGroupDisposition", $ResponseValues{QSharingGroupDisposition} ],
+    QSGDISP     => [ "QSGDisposition",		$ResponseValues{QSGDisposition} ],
+   # QSGDISP     => [ "QSGDisposition",		$ResponseValues{QSGDisposition} ],
     QSTATUS     => [ "QName" ],
     SET         => [ "Set",                     $ResponseValues{Yes} ],
     TASKNO      => [ "TaskNumber" ],
@@ -372,10 +432,25 @@ package MQSeries::Command::MQSC;
     DESCR       => [ "AuthInfoDesc" ],
     LDAPPWD     => [ "LDAPPassword" ],
     LDAPUSER    => [ "LDAPUserName" ],
-    QSGDISP     => [ "QSharingGroupDisposition", $ResponseValues{QSharingGroupDisposition} ],
+    QSGDISP     => [ "QSGDisposition",		$ResponseValues{QSGDisposition} ],
+    #QSGDISP     => [ "QSGDisposition",		$ResponseValues{QSGDisposition} ],
    },
 
-   CFStruct     => 
+   CFStruc => 
+   {
+    ALTDATE	=> [ "AlterationDate" ],
+    ALTTIME	=> [ "AlterationTime" ],
+    CFLEVEL     => [ "CFLevel" ],
+    CFSTRUCT    => [ "CFStrucName" ],
+    DESCR       => [ "CFStrucDesc" ],
+    RECOVER     => [ "Recovery",                $ResponseValues{Yes} ],
+   },
+
+   #
+   # NOTE: CFStruct is for backwards compatibility with pre-1.24 MQSC
+   #       New code should use CFStruc (no final 't')
+   #
+   CFStruct => 
    {
     ALTDATE	=> [ "AlterationDate" ],
     ALTTIME	=> [ "AlterationTime" ],
